@@ -18,13 +18,19 @@ from typing import Any, Dict, List, Sequence, Union
 from .literals import (
     ChannelMembershipTypeType,
     ChannelMessagePersistenceTypeType,
+    ChannelMessageStatusType,
     ChannelMessageTypeType,
     ChannelModeType,
     ChannelPrivacyType,
     ErrorCodeType,
+    FallbackActionType,
     SortOrderType,
 )
 
+if sys.version_info >= (3, 8):
+    from typing import Literal
+else:
+    from typing_extensions import Literal
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -33,15 +39,23 @@ else:
 
 __all__ = (
     "AppInstanceUserMembershipSummaryTypeDef",
+    "AssociateChannelFlowRequestRequestTypeDef",
     "BatchChannelMembershipsTypeDef",
     "BatchCreateChannelMembershipErrorTypeDef",
     "BatchCreateChannelMembershipRequestRequestTypeDef",
     "BatchCreateChannelMembershipResponseTypeDef",
+    "ChannelAssociatedWithFlowSummaryTypeDef",
     "ChannelBanSummaryTypeDef",
     "ChannelBanTypeDef",
+    "ChannelFlowCallbackRequestRequestTypeDef",
+    "ChannelFlowCallbackResponseTypeDef",
+    "ChannelFlowSummaryTypeDef",
+    "ChannelFlowTypeDef",
     "ChannelMembershipForAppInstanceUserSummaryTypeDef",
     "ChannelMembershipSummaryTypeDef",
     "ChannelMembershipTypeDef",
+    "ChannelMessageCallbackTypeDef",
+    "ChannelMessageStatusStructureTypeDef",
     "ChannelMessageSummaryTypeDef",
     "ChannelMessageTypeDef",
     "ChannelModeratedByAppInstanceUserSummaryTypeDef",
@@ -51,6 +65,8 @@ __all__ = (
     "ChannelTypeDef",
     "CreateChannelBanRequestRequestTypeDef",
     "CreateChannelBanResponseTypeDef",
+    "CreateChannelFlowRequestRequestTypeDef",
+    "CreateChannelFlowResponseTypeDef",
     "CreateChannelMembershipRequestRequestTypeDef",
     "CreateChannelMembershipResponseTypeDef",
     "CreateChannelModeratorRequestRequestTypeDef",
@@ -58,12 +74,15 @@ __all__ = (
     "CreateChannelRequestRequestTypeDef",
     "CreateChannelResponseTypeDef",
     "DeleteChannelBanRequestRequestTypeDef",
+    "DeleteChannelFlowRequestRequestTypeDef",
     "DeleteChannelMembershipRequestRequestTypeDef",
     "DeleteChannelMessageRequestRequestTypeDef",
     "DeleteChannelModeratorRequestRequestTypeDef",
     "DeleteChannelRequestRequestTypeDef",
     "DescribeChannelBanRequestRequestTypeDef",
     "DescribeChannelBanResponseTypeDef",
+    "DescribeChannelFlowRequestRequestTypeDef",
+    "DescribeChannelFlowResponseTypeDef",
     "DescribeChannelMembershipForAppInstanceUserRequestRequestTypeDef",
     "DescribeChannelMembershipForAppInstanceUserResponseTypeDef",
     "DescribeChannelMembershipRequestRequestTypeDef",
@@ -74,12 +93,18 @@ __all__ = (
     "DescribeChannelModeratorResponseTypeDef",
     "DescribeChannelRequestRequestTypeDef",
     "DescribeChannelResponseTypeDef",
+    "DisassociateChannelFlowRequestRequestTypeDef",
     "GetChannelMessageRequestRequestTypeDef",
     "GetChannelMessageResponseTypeDef",
+    "GetChannelMessageStatusRequestRequestTypeDef",
+    "GetChannelMessageStatusResponseTypeDef",
     "GetMessagingSessionEndpointResponseTypeDef",
     "IdentityTypeDef",
+    "LambdaConfigurationTypeDef",
     "ListChannelBansRequestRequestTypeDef",
     "ListChannelBansResponseTypeDef",
+    "ListChannelFlowsRequestRequestTypeDef",
+    "ListChannelFlowsResponseTypeDef",
     "ListChannelMembershipsForAppInstanceUserRequestRequestTypeDef",
     "ListChannelMembershipsForAppInstanceUserResponseTypeDef",
     "ListChannelMembershipsRequestRequestTypeDef",
@@ -88,17 +113,27 @@ __all__ = (
     "ListChannelMessagesResponseTypeDef",
     "ListChannelModeratorsRequestRequestTypeDef",
     "ListChannelModeratorsResponseTypeDef",
+    "ListChannelsAssociatedWithChannelFlowRequestRequestTypeDef",
+    "ListChannelsAssociatedWithChannelFlowResponseTypeDef",
     "ListChannelsModeratedByAppInstanceUserRequestRequestTypeDef",
     "ListChannelsModeratedByAppInstanceUserResponseTypeDef",
     "ListChannelsRequestRequestTypeDef",
     "ListChannelsResponseTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
+    "ListTagsForResourceResponseTypeDef",
     "MessagingSessionEndpointTypeDef",
+    "ProcessorConfigurationTypeDef",
+    "ProcessorTypeDef",
     "RedactChannelMessageRequestRequestTypeDef",
     "RedactChannelMessageResponseTypeDef",
     "ResponseMetadataTypeDef",
     "SendChannelMessageRequestRequestTypeDef",
     "SendChannelMessageResponseTypeDef",
+    "TagResourceRequestRequestTypeDef",
     "TagTypeDef",
+    "UntagResourceRequestRequestTypeDef",
+    "UpdateChannelFlowRequestRequestTypeDef",
+    "UpdateChannelFlowResponseTypeDef",
     "UpdateChannelMessageRequestRequestTypeDef",
     "UpdateChannelMessageResponseTypeDef",
     "UpdateChannelReadMarkerRequestRequestTypeDef",
@@ -116,6 +151,15 @@ AppInstanceUserMembershipSummaryTypeDef = TypedDict(
     total=False,
 )
 
+AssociateChannelFlowRequestRequestTypeDef = TypedDict(
+    "AssociateChannelFlowRequestRequestTypeDef",
+    {
+        "ChannelArn": str,
+        "ChannelFlowArn": str,
+        "ChimeBearer": str,
+    },
+)
+
 BatchChannelMembershipsTypeDef = TypedDict(
     "BatchChannelMembershipsTypeDef",
     {
@@ -170,6 +214,18 @@ BatchCreateChannelMembershipResponseTypeDef = TypedDict(
     },
 )
 
+ChannelAssociatedWithFlowSummaryTypeDef = TypedDict(
+    "ChannelAssociatedWithFlowSummaryTypeDef",
+    {
+        "Name": str,
+        "ChannelArn": str,
+        "Mode": ChannelModeType,
+        "Privacy": ChannelPrivacyType,
+        "Metadata": str,
+    },
+    total=False,
+)
+
 ChannelBanSummaryTypeDef = TypedDict(
     "ChannelBanSummaryTypeDef",
     {
@@ -189,6 +245,61 @@ ChannelBanTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredChannelFlowCallbackRequestRequestTypeDef = TypedDict(
+    "_RequiredChannelFlowCallbackRequestRequestTypeDef",
+    {
+        "CallbackId": str,
+        "ChannelArn": str,
+        "ChannelMessage": "ChannelMessageCallbackTypeDef",
+    },
+)
+_OptionalChannelFlowCallbackRequestRequestTypeDef = TypedDict(
+    "_OptionalChannelFlowCallbackRequestRequestTypeDef",
+    {
+        "DeleteResource": bool,
+    },
+    total=False,
+)
+
+
+class ChannelFlowCallbackRequestRequestTypeDef(
+    _RequiredChannelFlowCallbackRequestRequestTypeDef,
+    _OptionalChannelFlowCallbackRequestRequestTypeDef,
+):
+    pass
+
+
+ChannelFlowCallbackResponseTypeDef = TypedDict(
+    "ChannelFlowCallbackResponseTypeDef",
+    {
+        "ChannelArn": str,
+        "CallbackId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ChannelFlowSummaryTypeDef = TypedDict(
+    "ChannelFlowSummaryTypeDef",
+    {
+        "ChannelFlowArn": str,
+        "Name": str,
+        "Processors": List["ProcessorTypeDef"],
+    },
+    total=False,
+)
+
+ChannelFlowTypeDef = TypedDict(
+    "ChannelFlowTypeDef",
+    {
+        "ChannelFlowArn": str,
+        "Processors": List["ProcessorTypeDef"],
+        "Name": str,
+        "CreatedTimestamp": datetime,
+        "LastUpdatedTimestamp": datetime,
+    },
+    total=False,
+)
+
 ChannelMembershipForAppInstanceUserSummaryTypeDef = TypedDict(
     "ChannelMembershipForAppInstanceUserSummaryTypeDef",
     {
@@ -219,6 +330,37 @@ ChannelMembershipTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredChannelMessageCallbackTypeDef = TypedDict(
+    "_RequiredChannelMessageCallbackTypeDef",
+    {
+        "MessageId": str,
+    },
+)
+_OptionalChannelMessageCallbackTypeDef = TypedDict(
+    "_OptionalChannelMessageCallbackTypeDef",
+    {
+        "Content": str,
+        "Metadata": str,
+    },
+    total=False,
+)
+
+
+class ChannelMessageCallbackTypeDef(
+    _RequiredChannelMessageCallbackTypeDef, _OptionalChannelMessageCallbackTypeDef
+):
+    pass
+
+
+ChannelMessageStatusStructureTypeDef = TypedDict(
+    "ChannelMessageStatusStructureTypeDef",
+    {
+        "Value": ChannelMessageStatusType,
+        "Detail": str,
+    },
+    total=False,
+)
+
 ChannelMessageSummaryTypeDef = TypedDict(
     "ChannelMessageSummaryTypeDef",
     {
@@ -231,6 +373,7 @@ ChannelMessageSummaryTypeDef = TypedDict(
         "LastEditedTimestamp": datetime,
         "Sender": "IdentityTypeDef",
         "Redacted": bool,
+        "Status": "ChannelMessageStatusStructureTypeDef",
     },
     total=False,
 )
@@ -249,6 +392,7 @@ ChannelMessageTypeDef = TypedDict(
         "Sender": "IdentityTypeDef",
         "Redacted": bool,
         "Persistence": ChannelMessagePersistenceTypeType,
+        "Status": "ChannelMessageStatusStructureTypeDef",
     },
     total=False,
 )
@@ -305,6 +449,7 @@ ChannelTypeDef = TypedDict(
         "CreatedTimestamp": datetime,
         "LastMessageTimestamp": datetime,
         "LastUpdatedTimestamp": datetime,
+        "ChannelFlowArn": str,
     },
     total=False,
 )
@@ -327,6 +472,38 @@ CreateChannelBanResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredCreateChannelFlowRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateChannelFlowRequestRequestTypeDef",
+    {
+        "AppInstanceArn": str,
+        "Processors": Sequence["ProcessorTypeDef"],
+        "Name": str,
+        "ClientRequestToken": str,
+    },
+)
+_OptionalCreateChannelFlowRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateChannelFlowRequestRequestTypeDef",
+    {
+        "Tags": Sequence["TagTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateChannelFlowRequestRequestTypeDef(
+    _RequiredCreateChannelFlowRequestRequestTypeDef, _OptionalCreateChannelFlowRequestRequestTypeDef
+):
+    pass
+
+
+CreateChannelFlowResponseTypeDef = TypedDict(
+    "CreateChannelFlowResponseTypeDef",
+    {
+        "ChannelFlowArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 CreateChannelMembershipRequestRequestTypeDef = TypedDict(
     "CreateChannelMembershipRequestRequestTypeDef",
     {
@@ -408,6 +585,13 @@ DeleteChannelBanRequestRequestTypeDef = TypedDict(
     },
 )
 
+DeleteChannelFlowRequestRequestTypeDef = TypedDict(
+    "DeleteChannelFlowRequestRequestTypeDef",
+    {
+        "ChannelFlowArn": str,
+    },
+)
+
 DeleteChannelMembershipRequestRequestTypeDef = TypedDict(
     "DeleteChannelMembershipRequestRequestTypeDef",
     {
@@ -460,6 +644,21 @@ DescribeChannelBanResponseTypeDef = TypedDict(
     },
 )
 
+DescribeChannelFlowRequestRequestTypeDef = TypedDict(
+    "DescribeChannelFlowRequestRequestTypeDef",
+    {
+        "ChannelFlowArn": str,
+    },
+)
+
+DescribeChannelFlowResponseTypeDef = TypedDict(
+    "DescribeChannelFlowResponseTypeDef",
+    {
+        "ChannelFlow": "ChannelFlowTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 DescribeChannelMembershipForAppInstanceUserRequestRequestTypeDef = TypedDict(
     "DescribeChannelMembershipForAppInstanceUserRequestRequestTypeDef",
     {
@@ -544,6 +743,15 @@ DescribeChannelResponseTypeDef = TypedDict(
     },
 )
 
+DisassociateChannelFlowRequestRequestTypeDef = TypedDict(
+    "DisassociateChannelFlowRequestRequestTypeDef",
+    {
+        "ChannelArn": str,
+        "ChannelFlowArn": str,
+        "ChimeBearer": str,
+    },
+)
+
 GetChannelMessageRequestRequestTypeDef = TypedDict(
     "GetChannelMessageRequestRequestTypeDef",
     {
@@ -561,6 +769,23 @@ GetChannelMessageResponseTypeDef = TypedDict(
     },
 )
 
+GetChannelMessageStatusRequestRequestTypeDef = TypedDict(
+    "GetChannelMessageStatusRequestRequestTypeDef",
+    {
+        "ChannelArn": str,
+        "MessageId": str,
+        "ChimeBearer": str,
+    },
+)
+
+GetChannelMessageStatusResponseTypeDef = TypedDict(
+    "GetChannelMessageStatusResponseTypeDef",
+    {
+        "Status": "ChannelMessageStatusStructureTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 GetMessagingSessionEndpointResponseTypeDef = TypedDict(
     "GetMessagingSessionEndpointResponseTypeDef",
     {
@@ -578,6 +803,14 @@ IdentityTypeDef = TypedDict(
     total=False,
 )
 
+LambdaConfigurationTypeDef = TypedDict(
+    "LambdaConfigurationTypeDef",
+    {
+        "ResourceArn": str,
+        "InvocationType": Literal["ASYNC"],
+    },
+)
+
 _RequiredListChannelBansRequestRequestTypeDef = TypedDict(
     "_RequiredListChannelBansRequestRequestTypeDef",
     {
@@ -611,6 +844,37 @@ ListChannelBansResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredListChannelFlowsRequestRequestTypeDef = TypedDict(
+    "_RequiredListChannelFlowsRequestRequestTypeDef",
+    {
+        "AppInstanceArn": str,
+    },
+)
+_OptionalListChannelFlowsRequestRequestTypeDef = TypedDict(
+    "_OptionalListChannelFlowsRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListChannelFlowsRequestRequestTypeDef(
+    _RequiredListChannelFlowsRequestRequestTypeDef, _OptionalListChannelFlowsRequestRequestTypeDef
+):
+    pass
+
+
+ListChannelFlowsResponseTypeDef = TypedDict(
+    "ListChannelFlowsResponseTypeDef",
+    {
+        "ChannelFlows": List["ChannelFlowSummaryTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 _RequiredListChannelMembershipsForAppInstanceUserRequestRequestTypeDef = TypedDict(
     "_RequiredListChannelMembershipsForAppInstanceUserRequestRequestTypeDef",
     {
@@ -750,6 +1014,38 @@ ListChannelModeratorsResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredListChannelsAssociatedWithChannelFlowRequestRequestTypeDef = TypedDict(
+    "_RequiredListChannelsAssociatedWithChannelFlowRequestRequestTypeDef",
+    {
+        "ChannelFlowArn": str,
+    },
+)
+_OptionalListChannelsAssociatedWithChannelFlowRequestRequestTypeDef = TypedDict(
+    "_OptionalListChannelsAssociatedWithChannelFlowRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListChannelsAssociatedWithChannelFlowRequestRequestTypeDef(
+    _RequiredListChannelsAssociatedWithChannelFlowRequestRequestTypeDef,
+    _OptionalListChannelsAssociatedWithChannelFlowRequestRequestTypeDef,
+):
+    pass
+
+
+ListChannelsAssociatedWithChannelFlowResponseTypeDef = TypedDict(
+    "ListChannelsAssociatedWithChannelFlowResponseTypeDef",
+    {
+        "Channels": List["ChannelAssociatedWithFlowSummaryTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 _RequiredListChannelsModeratedByAppInstanceUserRequestRequestTypeDef = TypedDict(
     "_RequiredListChannelsModeratedByAppInstanceUserRequestRequestTypeDef",
     {
@@ -816,6 +1112,21 @@ ListChannelsResponseTypeDef = TypedDict(
     },
 )
 
+ListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestRequestTypeDef",
+    {
+        "ResourceARN": str,
+    },
+)
+
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
+    {
+        "Tags": List["TagTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 MessagingSessionEndpointTypeDef = TypedDict(
     "MessagingSessionEndpointTypeDef",
     {
@@ -824,6 +1135,23 @@ MessagingSessionEndpointTypeDef = TypedDict(
     total=False,
 )
 
+ProcessorConfigurationTypeDef = TypedDict(
+    "ProcessorConfigurationTypeDef",
+    {
+        "Lambda": "LambdaConfigurationTypeDef",
+    },
+)
+
+ProcessorTypeDef = TypedDict(
+    "ProcessorTypeDef",
+    {
+        "Name": str,
+        "Configuration": "ProcessorConfigurationTypeDef",
+        "ExecutionOrder": int,
+        "FallbackAction": FallbackActionType,
+    },
+)
+
 RedactChannelMessageRequestRequestTypeDef = TypedDict(
     "RedactChannelMessageRequestRequestTypeDef",
     {
@@ -885,10 +1213,19 @@ SendChannelMessageResponseTypeDef = TypedDict(
     {
         "ChannelArn": str,
         "MessageId": str,
+        "Status": "ChannelMessageStatusStructureTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
+    {
+        "ResourceARN": str,
+        "Tags": Sequence["TagTypeDef"],
+    },
+)
+
 TagTypeDef = TypedDict(
     "TagTypeDef",
     {
@@ -897,6 +1234,31 @@ TagTypeDef = TypedDict(
     },
 )
 
+UntagResourceRequestRequestTypeDef = TypedDict(
+    "UntagResourceRequestRequestTypeDef",
+    {
+        "ResourceARN": str,
+        "TagKeys": Sequence[str],
+    },
+)
+
+UpdateChannelFlowRequestRequestTypeDef = TypedDict(
+    "UpdateChannelFlowRequestRequestTypeDef",
+    {
+        "ChannelFlowArn": str,
+        "Processors": Sequence["ProcessorTypeDef"],
+        "Name": str,
+    },
+)
+
+UpdateChannelFlowResponseTypeDef = TypedDict(
+    "UpdateChannelFlowResponseTypeDef",
+    {
+        "ChannelFlowArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 _RequiredUpdateChannelMessageRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateChannelMessageRequestRequestTypeDef",
     {
@@ -927,6 +1289,7 @@ UpdateChannelMessageResponseTypeDef = TypedDict(
     {
         "ChannelArn": str,
         "MessageId": str,
+        "Status": "ChannelMessageStatusStructureTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
